<template>
  <ProTableQueryFilterBar @on-reset="reset">
    <template #query>
      <QueryFilterItem>
        <SearchInput
          v-model="extraParamState.title"
          style="width: 250px"
          placeholder="企业名/信用代码"
          @on-click-search="getList"
        >
        </SearchInput>
      </QueryFilterItem>
    </template>
  </ProTableQueryFilterBar>
  <ProTableV2
    v-bind="proTableProps"
    :columns="column"
    :operationBtns="operationBtns"
    :autoHeight="false"
    :tableProps="{
      maxHeight: '400px',
    }"
  >
  </ProTableV2>
  <MateriaDetailDialog v-bind="dialogProps"></MateriaDetailDialog>
</template>

<script setup lang="ts">
import {
  ProTableQueryFilterBar,
  QueryFilterItem,
  ProTableV2,
  SearchInput,
  useFormDialog,
  useTable,
  defineOperationBtns,
  defineColumns,
} from '@bole-core/components';
import MateriaDetailDialog from './MateriaDetailDialog.vue';
import { FourStreamsMaterialFileTableItem } from './types';
import { OrderInputType } from '@bole-core/core';
import * as informationServices from '@/services/api/Information';

defineOptions({
  name: 'DeclareEnterpriseTableView',
});

type Props = {};

const props = withDefaults(defineProps<Props>(), {});

const column = defineColumns([
  {
    id: '1',
    enCode: 'accDateTime',
    name: '帐号',
  },
  {
    id: '2',
    enCode: 'enterpriseName',
    name: '企业名称',
  },
  {
    id: '3',
    enCode: 'societyCreditCode',
    name: '信用代码',
  },
  {
    id: '4',
    enCode: 'contactPhone',
    name: '电话',
  },
  {
    id: '5',
    enCode: 'authType',
    name: '企业类型',
  },
  {
    id: '6',
    enCode: 'licenseUrl',
    name: '营业执照',
  },
  {
    id: '7',
    enCode: 'bankAccountInfo',
    name: '基本户信息',
  },
]);

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => openDialog(role),
    },
  },
]);

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetInformationForManageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        title: extraParamState.title,
      };
      let res = await informationServices.getInformationForManage(params);
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
      title: '',
    },
  }
);

const { dialogProps, handleEdit, editForm } = useFormDialog({
  defaultFormParams: {
    list: [] as FourStreamsMaterialFileTableItem[],
  },
});

function openDialog(row?: API.IncentivePaymentsManageListOutput) {
  handleEdit({
    list: [],
  });
}

defineExpose({
  getList,
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
